@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*
 
 import testtools
-import unittest
 
 from east import utils
 
@@ -12,7 +11,3 @@ class UtilsTestCase(testtools.TestCase):
         text = "Well, what a sunny day!"
         tokens = ["Well", "what", "a", "sunny", "day"]
         self.assertEqual(utils.tokenize(text), tokens)
-
-
-if __name__ == '__main__':
-    unittest.main()
